Copulalib
Description: usage page of the Copulalib
Keywords: copula, AMBHAS

# Classes

`vi`
  To calculate the vegetation indices. This class contain the following functions:

      	get_vi => To get the Vegetation Indices.
                        The followign indices can be calculated :
      								RVI
      								NDVI
      								IPVI
      								DVI
      								RNDVI
      								MRVI
      								MPRI
      								SAVI
      								EVI2
      								MGNDVI
      								MNDVI
      								BI
      								RGRI
      								GNDVI
      								NDRGI
      								NDVSI
      								RDI
      								TNDVI
      								GRVI
      								OSAVI
      								MGRVI
      								SLAVI
      								NDMI